<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar
        @on-reset="reset"
        @on-search="getList"
      >
        <template #query>
          <QueryFilterItem>
            <FieldSelect
              v-model="extraParamState.importChannel"
              placeholder="理赔渠道"
              :value-enum="insuranceClaimChannelListForSelect"
              clearable
              @change="getList()"
            />
          </QueryFilterItem>
          <QueryFilterItem>
            <FieldDatePicker
              v-model="extraParamState.creationDate"
              type="daterange"
              range-separator="~"
              start-placeholder="起始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
              tooltipContent="导入日期"
            ></FieldDatePicker>
          </QueryFilterItem>

          <!-- <QueryFilterItem>
            <FieldDatePicker
              v-model="extraParamState.creationTime"
              type="date"
              placeholder="导入日期"
              clearable
              @change="getList()"
              tooltipContent="导入日期"
            ></FieldDatePicker>
          </QueryFilterItem> -->
        </template>
        <template #btn>
          <el-button
            v-if="checkSubModuleItemShow('pageButton', 'exportBtn')"
            @click="handleExport()"
            icon="Download"
            type="primary"
            >导出</el-button
          >
        </template>
      </ProTableQueryFilterBar>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
    <BatchUploadOrderDialog v-bind="dialogBatchUploadOrderProps"></BatchUploadOrderDialog>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  ProTableQueryFilterBar,
  OperationBtnType,
  ProTableV2,
  SearchInput,
  LoadingLayout,
  AppContainer,
  QueryFilterItem,
  useTable,
  useFormDialog,
  FieldDatePicker,
  FieldSelect,
  FieldRadio,
  UploadUserFile,
} from '@bole-core/components';
import { useAccess, useInsuranceClaimChannelList } from '@/hooks';
import * as insuranceOrderServices from '@/services/api/InsuranceOrder';
import { Message, OrderInputType } from '@bole-core/core';
import { downloadFile, downloadFileByUrl, format, setOSSLink } from '@/utils';
import { ModelValueType } from 'element-plus';
import { OnJobFlagEnumText, insuranceTypeText } from '@/constants';
import BatchUploadOrderDialog from './components/BatchUploadOrderDialog.vue';

defineOptions({
  name: 'ExportManage',
});

const operationBtnMap: Record<string, OperationBtnType> = {
  // checkBtn: { emits: { onClick: (role) => goDetail(role) } },
  policyDownloadBtn: {
    emits: { onClick: (role) => handleDownload(role) },
    extraProps: {
      hide: (row: API.InsuranceOrderListOutput) => !( row.orderBillFile),
    },
  },
};

const { checkSubModuleItemShow, column, operationBtns } = useAccess({
  operationBtnMap,
});

const { insuranceClaimChannelListForSelect } = useInsuranceClaimChannelList();

const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params = createParams(pageIndex, pageSize);
      let res = await insuranceOrderServices.getInsuranceOrderPage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'id', order: OrderInputType.Desc }],
      // creationTime: '',
      importChannel: '',
      condition: '',
      onJobFlag: '',
      insuranceType: '',
      creationDate: [] as unknown as ModelValueType,
    },
    columnsRenderProps: {
      createTime: {
        type: 'date',
        format: 'YYYY/MM/DD',
      },
      insuranceBeginTime: {
        type: 'date',
        format: 'YYYY/MM/DD',
      },
      insuranceEndTime: {
        type: 'date',
        format: 'YYYY/MM/DD',
      },
    },
  }
);

function createParams(pageIndex: number, pageSize: number) {
  let params: API.QueryInsuranceOrderPageInput = {
    pageModel: {
      rows: pageSize,
      page: pageIndex,
      orderInput: extraParamState.orderInput,
    },
    importChannel: extraParamState.importChannel,
    beginCreationTime: format(extraParamState.creationDate?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
    endCreationTime: format(extraParamState.creationDate?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
    insuranceType: extraParamState.insuranceType,
    onJobFlag: extraParamState.onJobFlag,
    condition: extraParamState.condition,
  };
  return params;
}
async function handleExport() {
  try {
    if (paginationState.total === 0) {
      Message.warnMessage('没有数据可以导出哦~');
      return;
    }
    let params = createParams(paginationState.pageIndex, paginationState.pageSize);
    let res = await insuranceOrderServices.exportInsuranceOrderList(params, {
      responseType: 'blob',
      getResponse: true,
    });
    if (res) {
      downloadFile(res.data, `保单导出`, 'xlsx');
    }
  } catch (error) {}
}

// const router = useRouter();
// function goDetail(row: API.InsuranceOrderListOutput) {
//   router.push({
//     name: 'InsuranceClaimDetail',
//     params: {
//       id: row.id,
//     },
//   });
// }

const {
  dialogProps: dialogBatchUploadOrderProps,
  handleAdd: handleBatchUploadOrderAdd,
  editForm: batchUploadOrderForm,
} = useFormDialog({
  onConfirm: addInsuranceOrderBillFile,
  defaultFormParams: {
    orderNo: '',
    url: [] as UploadUserFile[],
  },
});

async function addInsuranceOrderBillFile() {
  try {
    let params: API.AddInsuranceOrderBillFile = {
      orderNo: batchUploadOrderForm.orderNo,
      orderBillFile: batchUploadOrderForm.url?.[0].path ?? '',
    };
    let res = await insuranceOrderServices.addInsuranceOrderBillFile(params);
    if (res) {
      Message.successMessage('操作成功');
      getList(paginationState.pageIndex);
    }
  } catch (error) {}
}

function handleDownload(row?: API.InsuranceOrderListOutput) {
  downloadFileByUrl(setOSSLink(row.orderBillFile));
}
</script>
